#!/bin/bash
#
# This shell script shows an example of how to make a bootable ISO of Windows PE
# that will automatically connect to a SAMBA server to start the automated
# installation of Windows 7 when it boots up.  The ISO can be booted from the
# network using PXELINUX and its `memdisk' module.  (Or, try GPXELINUX, which
# can load the ISO using HTTP instead of TFTP.)
#
# This script is just an example and is not installed with `wimlib'.  You, of
# course, need a Windows 7 DVD for certain necessary files.  (A copy of Windows
# PE may also be found in the Windows Automated Installation Kit.)
#
# `mkisofs' is a program provided by the `cdrkit' collection of programs.
#
# To customize the WIM, edit the `actionfile.txt' in this directory.
# To customize the command run on installation, edit the `install.cmd'
#     in this directory.
#

set -e

# The path to the mounted Windows 7 ISO on this computer.
WIN7_DIR=/mnt/windows7

# The name of the ISO file to create.
ISO_FILE=./winpe.iso

ISO_DIR=./winpeisobase
MNT_DIR=./winpe_mnt


rm -rf "$ISO_DIR" "$MNT_DIR"

mkdir -v -p "$ISO_DIR"/{boot,sources} "$MNT_DIR"

cp -v "$WIN7_DIR"/{bootmgr,boot/etfsboot.com} "$ISO_DIR"
cp -v "$WIN7_DIR"/boot/{bcd,boot.sdi} "$ISO_DIR"/boot

imagex export "$WIN7_DIR"/sources/boot.wim 2 --boot --compress \
			"$ISO_DIR/sources/boot.wim"

imagex mountrw "$ISO_DIR/sources/boot.wim" "$MNT_DIR"

mkdir -v "$MNT_DIR"/scripts

cp -v install "$MNT_DIR"/scripts/install.cmd
cp -v winpeshl.ini "$MNT_DIR"/Windows/System32
imagex unmount --commit "$MNT_DIR"

mkisofs -sysid ""  -A ""  -V "Microsoft Windows PE (x86)"  -d  -N  \
	-b etfsboot.com  -no-emul-boot   -c boot.cat  -hide etfsboot.com  \
	-hide boot.cat  -o "$ISO_FILE" "$ISO_DIR"

